Groups
========

   
Group Base
----------------

.. autoclass:: liesym.Group
   :members:
   :exclude-members: default_assumptions 

Lie Group
----------------
.. autoclass:: liesym.LieGroup
   :members:
   :undoc-members:
   :inherited-members: Basic
   :exclude-members: default_assumptions 

SO
----------------
.. autoclass:: liesym.SO
   :members:
   :undoc-members:
   :inherited-members: Basic
   :exclude-members: default_assumptions 
   
Sp
----------------
.. autoclass:: liesym.Sp
   :members:
   :undoc-members:
   :inherited-members: Basic
   :exclude-members: default_assumptions 

SU
----------------
.. autoclass:: liesym.SU
   :members:
   :undoc-members:
   :inherited-members: Basic
   :exclude-members: default_assumptions 

Z
----------------
.. autoclass:: liesym.Z
   :members:
   :undoc-members:
   :inherited-members: Basic
   :exclude-members: default_assumptions 

Functions
-----------------

.. automodule:: liesym.groups
   :members: generalized_gell_mann, commutator